### Data Gathering

This section explains how to fetch external datasets with GIS-MCP.
Currently covered:

- Administrative Boundaries (via `pygadm`)
- Climate (via `cdsapi`)
- Ecology (via `pygbif`)
- Movement (via `osmnx`)
- Satellite Imagery (via `pystac-client`)
- Land Cover (via `pystac-client`)

Each page lists requirements, parameters, and natural-language usage examples you can paste into Claude Desktop.
